#!/bin/sh -e
### BEGIN INIT INFO
# Provides:          remote-center
# Required-Start:    $local_fs $remote_fs $network
# Required-Stop:     $local_fs $remote_fs $network
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Start or stop the remote-center
### END INIT INFO

NAME=remote-center

PKG_PATH=/usr/local/AppCentral/remote-center
ASPORTAL_PATH=/usr/local/AppCentral/asportal
DAEMON=$PKG_PATH/bin/asremote-srv.pyc
WATCH_DAEMON=$PKG_PATH/usr/daemon/watchDaemon
PID_FILE=/var/run/asremote-srv.pid

if [ ! -e $PKG_PATH/CONTROL/env.sh ]; then
    echo "Can't find $PKG_PATH/CONTROL/env.sh"
    exit 1
fi

source $PKG_PATH/CONTROL/env.sh

. /lib/lsb/init-functions

start_daemon () {

    echo 'starting >>'

    [ -e "$PID_FILE" ] && stop_daemon

    [ -e $PKG_PATH/asremote-srv.log ] && mv $PKG_PATH/asremote-srv.log $PKG_PATH/asremote-srv_old.log
    [ -e "/usr/local/etc/init.d/P10remote-center" ] || ln -s $PKG_PATH/CONTROL/start-stop.sh /usr/local/etc/init.d/P10remote-center

    if [ -e "$ASPORTAL_PATH" ]; then
        echo "start $DAEMON"
        python $DAEMON start
    fi

    reload_ir

    echo 'starting <<'
}

stop_daemon () {
    echo 'stopping >>'

    stop_ir

    [ -e "/usr/local/etc/init.d/P10remote-center" ] && rm /usr/local/etc/init.d/P10remote-center

    [ -e "$PID_FILE" ] &&  ( echo "stop $DAEMON" &&  python $DAEMON stop & )

    i=10
    while [ $i -ne 0 ]; do
        [ ! -e "$PID_FILE" ] && echo "Daemon stop !" &&  break
        echo "count down: $i"
        i=`expr $i - 1`
        if [ $i -eq 0 ]; then
            echo "kill daemon forcibly!"
            kill -9 `cat $PID_FILE` && rm $PID_FILE
        fi
        sleep 1
    done

    echo 'stopping <<'
}

suspend_daemon () {
    stop_ir
    python $DAEMON suspend
}


resume_daemon () {
    python $DAEMON resume
    reload_ir
}

stop_ir (){
    if [ -n "$(pidof ir)" ]; then
        echo "stop ir"
        /usr/bin/killall ir
    fi
    if [ -n "$(pidof ir603snr)" ]; then
        echo "stop ir603snr"
        /usr/bin/killall ir603snr
    fi
    if [ -n "$(pidof xsel)" ]; then
        echo "stop xsel"
        /usr/bin/killall xsel
    fi
}

reload_ir (){
    stop_ir
    if [ -e "$ASPORTAL_PATH" ]; then
        echo "start ir"
        [ -e $PKG_PATH/bin/ir ] && $PKG_PATH/bin/ir remote -dev /dev/ttyS2 -kdelay 200 -file $PKG_PATH/bm_asir.txt -epath $PKG_PATH/bin/ir_key_mapping > /dev/null &
    else
        echo "start ir"
        [ -e $PKG_PATH/bin/ir ] && $PKG_PATH/bin/ir remote -dev /dev/ttyS2 -kdelay 200 -file $PKG_PATH/bm_asir.txt -epath $PKG_PATH/bin/ir_key_mapping_source > /dev/null &
    fi
}

case $1 in
    "start")
        #log_daemon_msg "Starting daemon" "$NAME..." "."
        start_daemon
        log_end_msg 0
        ;;
    "resume")
        resume_daemon
        ;;
    "stop")
        log_daemon_msg "Stopping daemon" "$NAME..." "."
        stop_daemon
        log_end_msg 0
        ;;
    "suspend")
        #log_daemon_msg "Stopping daemon" "$NAME..." "."
        suspend_daemon
        log_end_msg 0
        ;;
    "restart")
        log_daemon_msg "Restarting daemon" "$NAME..." "."
        stop_daemon
        start_daemon
        log_end_msg 0
        ;;
    "reload_ir")
        reload_ir
        ;;
    *)
        echo "Usage: /etc/init.d/$NAME {start|resume|stop|suspend|restart}"
        logger_daemon_msg "*"
        exit 2
        ;;
esac

exit 0

